@@ -40,7 +40,8 @@ struct curl_impl
         ssl_cert_error,
         ssl_key_error,
         protocol_error,
-        proxy_error
+        proxy_error,
+        client_crl_error
     };
 
     error_mode test_failure_mode = error_mode::success;
@@ -57,7 +58,7 @@ struct curl_impl
     std::function<size_t(char*, size_t, size_t, void*)> read_function;
     void* read_data; // Where to read the request body from
 
-    std::string request_url, cookie, cacert, client_cert, client_key, proxy;
+    std::string request_url, cookie, cacert, client_cert, client_key, client_crl, proxy;
     long protocols;
     long connect_timeout;
     http_method method = http_method::get;
