@@ -26,6 +26,7 @@ using namespace leatherman::util::posix;
 using namespace leatherman::execution;
 using namespace leatherman::logging;
 using namespace leatherman::file_util;
+using namespace boost::algorithm;
 using namespace boost::filesystem;
 
 // Declare environ for OSX
@@ -139,8 +140,33 @@ namespace leatherman { namespace execution {
         return fs.st_mode & S_IXOTH;
     }
 
-    string which(string const& file, vector<string> const& directories)
+    bool is_builtin(string const& file)
     {
+        string data;
+        string cmd = "type ";
+        cmd.append(file);
+        const int buffer_offset = 128;
+        const int max_buffer = buffer_offset + file.length();
+        char buffer[max_buffer];
+        FILE *stream = popen(cmd.c_str(), "r");
+        if (stream != nullptr) {
+            rewind(stream);
+            if (fgets(buffer, max_buffer, stream) != NULL){
+                data.append(buffer);
+            }
+            pclose(stream);
+        }
+
+        return contains(data, "builtin");
+    }
+
+    string which(string const& file, vector<string> const& directories, bool expand)
+    {
+        // if it is builtin, just return it
+        if ( !expand && is_builtin(file) ) {
+            return file;
+        }
+
         // If the file is already absolute, return it if it's executable
         path p = file;
         boost::system::error_code ec;
@@ -314,9 +340,29 @@ namespace leatherman { namespace execution {
         }
 
         // Close all open file descriptors above stderr
-        for (uint64_t i = (STDERR_FILENO + 1); i < max_fd; ++i) {
-            close(i);
+#ifdef HAS_CLOSEFROM
+        closefrom(STDERR_FILENO + 1);
+#else
+        uint64_t fd;
+        const char* fdpath = "/proc/self/fd";
+        std::list<uint64_t> fd_list;
+
+        if (is_directory(fdpath)) {
+            for (const directory_entry& dent : directory_iterator(fdpath)) {
+                fd = atol(dent.path().filename().c_str());
+                if (fd >= (STDERR_FILENO + 1)) {
+                    fd_list.push_back(fd);
+                }
+            }
+            for (auto fd : fd_list) {
+                close(fd);
+            }
+        } else {
+            for (uint64_t i = (STDERR_FILENO + 1); i < max_fd; ++i) {
+                close(i);
+            }
         }
+#endif  // HAS_CLOSEFROM
 
         // Execute the given program; this should not return if successful
         execve(program, const_cast<char* const*>(argv), const_cast<char* const*>(envp));
@@ -483,9 +529,14 @@ namespace leatherman { namespace execution {
                 kill(-child, SIGKILL);
             }
             // Wait for the child to exit
-            if (waitpid(child, &status, 0) == -1) {
-                LOG_DEBUG(format_error(_("waitpid failed")));
-                return;
+            while (waitpid(child, &status, 0) == -1) {
+                if ( errno == EINTR ) {
+                    LOG_DEBUG(format_error(_("waitpid was interrupted by a signal, retrying")));
+                    continue;
+                } else {
+                    LOG_DEBUG(format_error(_("waitpid failed")));
+                    return;
+                }
             }
             if (WIFEXITED(status)) {
                 status = static_cast<char>(WEXITSTATUS(status));
