@@ -72,8 +72,13 @@ namespace leatherman { namespace execution {
         return isfile;
     }
 
-    string which(string const& file, vector<string> const& directories)
+    string which(string const& file, vector<string> const& directories, bool expand)
     {
+        // On Windows is not supported to turn off command expansion by setting expand to false
+        if (!expand) {
+            LOG_ERROR("Unsupported argument on Windows expand with value false");
+            throw std::invalid_argument("Unsupported argument on Windows");
+        }
         // On Windows, everything has execute permission; Ruby determined
         // executability based on extension {com, exe, bat, cmd}. We'll do the
         // same check here using extpath_helper.
