@@ -5,6 +5,21 @@ using namespace std;
 
 namespace leatherman { namespace util {
 
+    int environment::get_int(string const& name, int default_value)
+    {
+        auto variable = boost::nowide::getenv(name.c_str());
+        if (!variable) {
+            return default_value;
+        }
+
+        try {
+            return stoi(variable);
+        }
+        catch (invalid_argument&) {
+            return default_value;
+        }
+    }
+
     bool environment::get(string const& name, string& value)
     {
         auto variable = boost::nowide::getenv(name.c_str());
